# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class ConversationsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_conversation(self, **kwargs):  # noqa: E501
        """Creates a conversation with customer and the team member  # noqa: E501

        _in snippets: platform.api.conversations.addConversation_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_conversation(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddConversationRequestModel body:
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_conversation_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_conversation_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_conversation_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a conversation with customer and the team member  # noqa: E501

        _in snippets: platform.api.conversations.addConversation_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_conversation_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddConversationRequestModel body:
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_conversation" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assign(self, conversation_id, **kwargs):  # noqa: E501
        """Takes a conversation and assigns it to one or more groups/users  # noqa: E501

        _in snippets: platform.api.conversations.assign_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param list[str] group_ids: The apiId or internal id
        :param list[int] team_member_ids:
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assign_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assign_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def assign_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Takes a conversation and assigns it to one or more groups/users  # noqa: E501

        _in snippets: platform.api.conversations.assign_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param list[str] group_ids: The apiId or internal id
        :param list[int] team_member_ids:
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'group_ids', 'team_member_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `assign`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'team_member_ids' in params:
            query_params.append(('teamMemberIds', params['team_member_ids']))  # noqa: E501
            collection_formats['teamMemberIds'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/assign', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assign_bot(self, conversation_id, **kwargs):  # noqa: E501
        """Takes a conversation and assigns it to a bot  # noqa: E501

        _in snippets: platform.api.conversations.assignBot_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_bot(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int bot_id:
        :param str bot_api_id:
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assign_bot_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assign_bot_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def assign_bot_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Takes a conversation and assigns it to a bot  # noqa: E501

        _in snippets: platform.api.conversations.assignBot_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_bot_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int bot_id:
        :param str bot_api_id:
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'bot_id', 'bot_api_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assign_bot" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `assign_bot`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []
        if 'bot_id' in params:
            query_params.append(('botId', params['bot_id']))  # noqa: E501
        if 'bot_api_id' in params:
            query_params.append(('botApiId', params['bot_api_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/assign_bot', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def close(self, conversation_id, team_member_id, **kwargs):  # noqa: E501
        """Closes the requested conversation  # noqa: E501

        _in snippets: platform.api.conversations.close_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.close(conversation_id, team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int team_member_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.close_with_http_info(conversation_id, team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.close_with_http_info(conversation_id, team_member_id, **kwargs)  # noqa: E501
            return data

    def close_with_http_info(self, conversation_id, team_member_id, **kwargs):  # noqa: E501
        """Closes the requested conversation  # noqa: E501

        _in snippets: platform.api.conversations.close_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.close_with_http_info(conversation_id, team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int team_member_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method close" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `close`")  # noqa: E501
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `close`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []
        if 'team_member_id' in params:
            query_params.append(('teamMemberId', params['team_member_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/close', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def escalate(self, conversation_id, **kwargs):  # noqa: E501
        """Takes an active conversation handled by a bot, and escalates it to groups or teamMembers  # noqa: E501

        _in snippets: platform.api.conversations.escalate_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.escalate(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param list[str] group_ids: The apiId or internal id
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.escalate_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.escalate_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def escalate_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Takes an active conversation handled by a bot, and escalates it to groups or teamMembers  # noqa: E501

        _in snippets: platform.api.conversations.escalate_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.escalate_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param list[str] group_ids: The apiId or internal id
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'group_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method escalate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `escalate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/escalate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_active(self, team_member_id, **kwargs):  # noqa: E501
        """Gets all the active conversations for a team member  # noqa: E501

        _in snippets: platform.api.conversations.getActive_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int first:
        :param int max:
        :return: ConversationModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_active_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_active_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_active_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets all the active conversations for a team member  # noqa: E501

        _in snippets: platform.api.conversations.getActive_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int first:
        :param int max:
        :return: ConversationModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_active`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/active/team_members/{teamMemberId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_active_for_bot(self, bot_id, **kwargs):  # noqa: E501
        """Gets all the active conversations for a bot  # noqa: E501

        _in snippets: platform.api.conversations.getActiveForBot_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_for_bot(bot_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int bot_id: (required)
        :param int first:
        :param int max:
        :return: ConversationModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_active_for_bot_with_http_info(bot_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_active_for_bot_with_http_info(bot_id, **kwargs)  # noqa: E501
            return data

    def get_active_for_bot_with_http_info(self, bot_id, **kwargs):  # noqa: E501
        """Gets all the active conversations for a bot  # noqa: E501

        _in snippets: platform.api.conversations.getActiveForBot_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_for_bot_with_http_info(bot_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int bot_id: (required)
        :param int first:
        :param int max:
        :return: ConversationModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bot_id', 'first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active_for_bot" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bot_id' is set
        if ('bot_id' not in params or
                params['bot_id'] is None):
            raise ValueError("Missing the required parameter `bot_id` when calling `get_active_for_bot`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bot_id' in params:
            path_params['botId'] = params['bot_id']  # noqa: E501

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/active/bots/{botId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_active_for_customer(self, customer_id, **kwargs):  # noqa: E501
        """Gets all the active conversations for a customer  # noqa: E501

        _in snippets: platform.api.conversations.getActiveForCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_for_customer(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param int first:
        :param int max:
        :return: ConversationModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_active_for_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_active_for_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def get_active_for_customer_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Gets all the active conversations for a customer  # noqa: E501

        _in snippets: platform.api.conversations.getActiveForCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_for_customer_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param int first:
        :param int max:
        :return: ConversationModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active_for_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `get_active_for_customer`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/active/customers/{customerId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_active_for_customer_by_channel_id(self, customer_channel_id, **kwargs):  # noqa: E501
        """Gets all the active conversations for a customer  # noqa: E501

        _in snippets: platform.api.conversations.getActiveForCustomerByChannelId_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_for_customer_by_channel_id(customer_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_channel_id: (required)
        :return: list[ConversationModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_active_for_customer_by_channel_id_with_http_info(customer_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_active_for_customer_by_channel_id_with_http_info(customer_channel_id, **kwargs)  # noqa: E501
            return data

    def get_active_for_customer_by_channel_id_with_http_info(self, customer_channel_id, **kwargs):  # noqa: E501
        """Gets all the active conversations for a customer  # noqa: E501

        _in snippets: platform.api.conversations.getActiveForCustomerByChannelId_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_for_customer_by_channel_id_with_http_info(customer_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_channel_id: (required)
        :return: list[ConversationModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_channel_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active_for_customer_by_channel_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_channel_id' is set
        if ('customer_channel_id' not in params or
                params['customer_channel_id'] is None):
            raise ValueError("Missing the required parameter `customer_channel_id` when calling `get_active_for_customer_by_channel_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_channel_id' in params:
            path_params['customerChannelId'] = params['customer_channel_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/active/customer_channels/{customerChannelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ConversationModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_active_for_customer_by_channel_key(self, type, key, **kwargs):  # noqa: E501
        """Gets all the active conversations for a customer  # noqa: E501

        _in snippets: platform.api.conversations.getActiveForCustomerByChannelKey_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_for_customer_by_channel_key(type, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str type: (required)
        :param str key: (required)
        :return: list[ConversationModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_active_for_customer_by_channel_key_with_http_info(type, key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_active_for_customer_by_channel_key_with_http_info(type, key, **kwargs)  # noqa: E501
            return data

    def get_active_for_customer_by_channel_key_with_http_info(self, type, key, **kwargs):  # noqa: E501
        """Gets all the active conversations for a customer  # noqa: E501

        _in snippets: platform.api.conversations.getActiveForCustomerByChannelKey_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_for_customer_by_channel_key_with_http_info(type, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str type: (required)
        :param str key: (required)
        :return: list[ConversationModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['type', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active_for_customer_by_channel_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'type' is set
        if ('type' not in params or
                params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `get_active_for_customer_by_channel_key`")  # noqa: E501
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `get_active_for_customer_by_channel_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'type' in params:
            path_params['type'] = params['type']  # noqa: E501
        if 'key' in params:
            path_params['key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/active/customer_channels/channel_types/{type}/channel_keys/{key}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ConversationModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_conversation(self, conversation_id, **kwargs):  # noqa: E501
        """Gets a conversation based on its internal id.  # noqa: E501

        _in snippets: platform.api.conversations.getConversation_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_conversation(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_conversation_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_conversation_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def get_conversation_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Gets a conversation based on its internal id.  # noqa: E501

        _in snippets: platform.api.conversations.getConversation_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_conversation_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conversation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_conversation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_conversation_messages(self, conversation_id, **kwargs):  # noqa: E501
        """Gets messages for a conversation  # noqa: E501

        _in snippets: platform.api.conversations.getConversationMessages_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_conversation_messages(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int less_or_equal_timestamp:
        :param int desired_max:
        :param bool filter_opted_out:
        :param bool exclude_system_messages:
        :return: list[MessageModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_conversation_messages_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_conversation_messages_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def get_conversation_messages_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Gets messages for a conversation  # noqa: E501

        _in snippets: platform.api.conversations.getConversationMessages_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_conversation_messages_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int less_or_equal_timestamp:
        :param int desired_max:
        :param bool filter_opted_out:
        :param bool exclude_system_messages:
        :return: list[MessageModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'less_or_equal_timestamp', 'desired_max', 'filter_opted_out', 'exclude_system_messages']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conversation_messages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_conversation_messages`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []
        if 'less_or_equal_timestamp' in params:
            query_params.append(('lessOrEqualTimestamp', params['less_or_equal_timestamp']))  # noqa: E501
        if 'desired_max' in params:
            query_params.append(('desiredMax', params['desired_max']))  # noqa: E501
        if 'filter_opted_out' in params:
            query_params.append(('filterOptedOut', params['filter_opted_out']))  # noqa: E501
        if 'exclude_system_messages' in params:
            query_params.append(('excludeSystemMessages', params['exclude_system_messages']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/messages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MessageModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_for_customer(self, customer_id, **kwargs):  # noqa: E501
        """Gets all messages for a customer, as visible by a team member  # noqa: E501

        _in snippets: platform.api.conversations.getForCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_for_customer(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param int viewable_by_team_member_id:
        :param int less_or_equal_timestamp:
        :param int desired_max:
        :return: list[MessageModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_for_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_for_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def get_for_customer_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Gets all messages for a customer, as visible by a team member  # noqa: E501

        _in snippets: platform.api.conversations.getForCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_for_customer_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: (required)
        :param int viewable_by_team_member_id:
        :param int less_or_equal_timestamp:
        :param int desired_max:
        :return: list[MessageModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'viewable_by_team_member_id', 'less_or_equal_timestamp', 'desired_max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_for_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `get_for_customer`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []
        if 'viewable_by_team_member_id' in params:
            query_params.append(('viewableByTeamMemberId', params['viewable_by_team_member_id']))  # noqa: E501
        if 'less_or_equal_timestamp' in params:
            query_params.append(('lessOrEqualTimestamp', params['less_or_equal_timestamp']))  # noqa: E501
        if 'desired_max' in params:
            query_params.append(('desiredMax', params['desired_max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/customers/{customerId}/messages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MessageModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_inbox(self, team_member_id, **kwargs):  # noqa: E501
        """Gets all the conversations in the team members inbox.  # noqa: E501

        _in snippets: platform.api.conversations.getInbox_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int first:
        :param int max:
        :param bool oldest_first:
        :return: ConversationModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_inbox_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_inbox_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_inbox_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets all the conversations in the team members inbox.  # noqa: E501

        _in snippets: platform.api.conversations.getInbox_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int first:
        :param int max:
        :param bool oldest_first:
        :return: ConversationModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'first', 'max', 'oldest_first']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_inbox" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_inbox`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501
        if 'oldest_first' in params:
            query_params.append(('oldestFirst', params['oldest_first']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/inbox/team_members/{teamMemberId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_smart_link(self, conversation_id, smart_link_id, **kwargs):  # noqa: E501
        """Creates a smart link for the customer involved in the conversation  # noqa: E501

        _in snippets: platform.api.conversations.getSmartLink_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_smart_link(conversation_id, smart_link_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int smart_link_id: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_smart_link_with_http_info(conversation_id, smart_link_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_smart_link_with_http_info(conversation_id, smart_link_id, **kwargs)  # noqa: E501
            return data

    def get_smart_link_with_http_info(self, conversation_id, smart_link_id, **kwargs):  # noqa: E501
        """Creates a smart link for the customer involved in the conversation  # noqa: E501

        _in snippets: platform.api.conversations.getSmartLink_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_smart_link_with_http_info(conversation_id, smart_link_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int smart_link_id: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'smart_link_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_smart_link" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_smart_link`")  # noqa: E501
        # verify the required parameter 'smart_link_id' is set
        if ('smart_link_id' not in params or
                params['smart_link_id'] is None):
            raise ValueError("Missing the required parameter `smart_link_id` when calling `get_smart_link`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501
        if 'smart_link_id' in params:
            path_params['smartLinkId'] = params['smart_link_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/smart_link/{smartLinkId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def opt_out(self, conversation_id, **kwargs):  # noqa: E501
        """Opted out customers can not receive any additional messages from this conversations until opted back in  # noqa: E501

        _in snippets: platform.api.conversations.optOut_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.opt_out(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param bool body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.opt_out_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.opt_out_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def opt_out_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Opted out customers can not receive any additional messages from this conversations until opted back in  # noqa: E501

        _in snippets: platform.api.conversations.optOut_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.opt_out_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param bool body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method opt_out" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `opt_out`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/optOut', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_message(self, conversation_id, **kwargs):  # noqa: E501
        """Posts a message to an active conversation  # noqa: E501

        _in snippets: platform.api.conversations.postMessage_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_message(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param PostMessageModel body:
        :return: MessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_message_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_message_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def post_message_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Posts a message to an active conversation  # noqa: E501

        _in snippets: platform.api.conversations.postMessage_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_message_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param PostMessageModel body:
        :return: MessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_message" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `post_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/message', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MessageModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_whisper(self, conversation_id, **kwargs):  # noqa: E501
        """Posts a whisper to an active conversation  # noqa: E501

        _in snippets: platform.api.conversations.postWhisper_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_whisper(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param PostWhisperModel body:
        :return: MessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_whisper_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_whisper_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def post_whisper_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Posts a whisper to an active conversation  # noqa: E501

        _in snippets: platform.api.conversations.postWhisper_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_whisper_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param PostWhisperModel body:
        :return: MessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_whisper" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `post_whisper`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/whisper', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MessageModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_team_member_from_conversation(self, conversation_id, team_member_id, **kwargs):  # noqa: E501
        """Removes a team member from a conversation.  # noqa: E501

        _in snippets: platform.api.conversations.removeTeamMemberFromConversation_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_team_member_from_conversation(conversation_id, team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int team_member_id: (required)
        :param RemoveTeamMemberFromConversationRequestModel body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_team_member_from_conversation_with_http_info(conversation_id, team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_team_member_from_conversation_with_http_info(conversation_id, team_member_id, **kwargs)  # noqa: E501
            return data

    def remove_team_member_from_conversation_with_http_info(self, conversation_id, team_member_id, **kwargs):  # noqa: E501
        """Removes a team member from a conversation.  # noqa: E501

        _in snippets: platform.api.conversations.removeTeamMemberFromConversation_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_team_member_from_conversation_with_http_info(conversation_id, team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int team_member_id: (required)
        :param RemoveTeamMemberFromConversationRequestModel body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'team_member_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_team_member_from_conversation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `remove_team_member_from_conversation`")  # noqa: E501
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `remove_team_member_from_conversation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/team_members/{teamMemberId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def take(self, conversation_id, **kwargs):  # noqa: E501
        """Takes a pending conversation and moves it into an active state, ready for communication  # noqa: E501

        _in snippets: platform.api.conversations.take_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.take(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int team_member_id:
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.take_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.take_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def take_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Takes a pending conversation and moves it into an active state, ready for communication  # noqa: E501

        _in snippets: platform.api.conversations.take_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.take_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param int team_member_id:
        :return: ConversationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method take" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `take`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []
        if 'team_member_id' in params:
            query_params.append(('teamMemberId', params['team_member_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/take', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConversationModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_membership(self, conversation_id, **kwargs):  # noqa: E501
        """Updates the team members presences in conversation, optionally add it to their Inbox, Active Chats, or removing it altogether  # noqa: E501

        _in snippets: platform.api.conversations.updateMembership_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_membership(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param UpdateMembershipModel body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_membership_with_http_info(conversation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_membership_with_http_info(conversation_id, **kwargs)  # noqa: E501
            return data

    def update_membership_with_http_info(self, conversation_id, **kwargs):  # noqa: E501
        """Updates the team members presences in conversation, optionally add it to their Inbox, Active Chats, or removing it altogether  # noqa: E501

        _in snippets: platform.api.conversations.updateMembership_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_membership_with_http_info(conversation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int conversation_id: (required)
        :param UpdateMembershipModel body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_membership" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params or
                params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `update_membership`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/conversations/{conversationId}/update_membership', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddOrUpdateAutomationFulfillmentModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'whisper': 'str',
        'instant_app_schema_api_id': 'str',
        'instant_app_message': 'str',
        'instant_app_parameters': 'str',
        'instant_app_locale': 'str',
        'upload_id': 'int',
        'complete_conversation': 'bool',
        'set_global_opt_out': 'bool',
        'clear_global_opt_out': 'bool',
        'snippet_code': 'str',
        'escalate_groups': 'list[str]',
        'add_to_contact_lists': 'list[str]',
        'remove_from_contact_lists': 'list[str]',
        'remove_from_all_contact_lists': 'bool',
        'add_tags': 'list[str]',
        'remove_tags': 'list[str]',
        'data': 'dict(str, str)'
    }

    attribute_map = {
        'message': 'message',
        'whisper': 'whisper',
        'instant_app_schema_api_id': 'instantAppSchemaApiId',
        'instant_app_message': 'instantAppMessage',
        'instant_app_parameters': 'instantAppParameters',
        'instant_app_locale': 'instantAppLocale',
        'upload_id': 'uploadId',
        'complete_conversation': 'completeConversation',
        'set_global_opt_out': 'setGlobalOptOut',
        'clear_global_opt_out': 'clearGlobalOptOut',
        'snippet_code': 'snippetCode',
        'escalate_groups': 'escalateGroups',
        'add_to_contact_lists': 'addToContactLists',
        'remove_from_contact_lists': 'removeFromContactLists',
        'remove_from_all_contact_lists': 'removeFromAllContactLists',
        'add_tags': 'addTags',
        'remove_tags': 'removeTags',
        'data': 'data'
    }

    def __init__(self, message=None, whisper=None, instant_app_schema_api_id=None, instant_app_message=None, instant_app_parameters=None, instant_app_locale=None, upload_id=None, complete_conversation=None, set_global_opt_out=None, clear_global_opt_out=None, snippet_code=None, escalate_groups=None, add_to_contact_lists=None, remove_from_contact_lists=None, remove_from_all_contact_lists=None, add_tags=None, remove_tags=None, data=None):  # noqa: E501
        """AddOrUpdateAutomationFulfillmentModel - a model defined in Swagger"""  # noqa: E501
        self._message = None
        self._whisper = None
        self._instant_app_schema_api_id = None
        self._instant_app_message = None
        self._instant_app_parameters = None
        self._instant_app_locale = None
        self._upload_id = None
        self._complete_conversation = None
        self._set_global_opt_out = None
        self._clear_global_opt_out = None
        self._snippet_code = None
        self._escalate_groups = None
        self._add_to_contact_lists = None
        self._remove_from_contact_lists = None
        self._remove_from_all_contact_lists = None
        self._add_tags = None
        self._remove_tags = None
        self._data = None
        self.discriminator = None
        if message is not None:
            self.message = message
        if whisper is not None:
            self.whisper = whisper
        if instant_app_schema_api_id is not None:
            self.instant_app_schema_api_id = instant_app_schema_api_id
        if instant_app_message is not None:
            self.instant_app_message = instant_app_message
        if instant_app_parameters is not None:
            self.instant_app_parameters = instant_app_parameters
        if instant_app_locale is not None:
            self.instant_app_locale = instant_app_locale
        if upload_id is not None:
            self.upload_id = upload_id
        if complete_conversation is not None:
            self.complete_conversation = complete_conversation
        if set_global_opt_out is not None:
            self.set_global_opt_out = set_global_opt_out
        if clear_global_opt_out is not None:
            self.clear_global_opt_out = clear_global_opt_out
        if snippet_code is not None:
            self.snippet_code = snippet_code
        if escalate_groups is not None:
            self.escalate_groups = escalate_groups
        if add_to_contact_lists is not None:
            self.add_to_contact_lists = add_to_contact_lists
        if remove_from_contact_lists is not None:
            self.remove_from_contact_lists = remove_from_contact_lists
        if remove_from_all_contact_lists is not None:
            self.remove_from_all_contact_lists = remove_from_all_contact_lists
        if add_tags is not None:
            self.add_tags = add_tags
        if remove_tags is not None:
            self.remove_tags = remove_tags
        if data is not None:
            self.data = data

    @property
    def message(self):
        """Gets the message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        The message to send to the user  # noqa: E501

        :return: The message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AddOrUpdateAutomationFulfillmentModel.

        The message to send to the user  # noqa: E501

        :param message: The message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def whisper(self):
        """Gets the whisper of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :return: The whisper of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._whisper

    @whisper.setter
    def whisper(self, whisper):
        """Sets the whisper of this AddOrUpdateAutomationFulfillmentModel.

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :param whisper: The whisper of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._whisper = whisper

    @property
    def instant_app_schema_api_id(self):
        """Gets the instant_app_schema_api_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        The programmatic, unique id of the schema for this Instant App Schema.  # noqa: E501

        :return: The instant_app_schema_api_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_schema_api_id

    @instant_app_schema_api_id.setter
    def instant_app_schema_api_id(self, instant_app_schema_api_id):
        """Sets the instant_app_schema_api_id of this AddOrUpdateAutomationFulfillmentModel.

        The programmatic, unique id of the schema for this Instant App Schema.  # noqa: E501

        :param instant_app_schema_api_id: The instant_app_schema_api_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._instant_app_schema_api_id = instant_app_schema_api_id

    @property
    def instant_app_message(self):
        """Gets the instant_app_message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :return: The instant_app_message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_message

    @instant_app_message.setter
    def instant_app_message(self, instant_app_message):
        """Sets the instant_app_message of this AddOrUpdateAutomationFulfillmentModel.

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :param instant_app_message: The instant_app_message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._instant_app_message = instant_app_message

    @property
    def instant_app_parameters(self):
        """Gets the instant_app_parameters of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Instant App parameters passed into the Instant App  # noqa: E501

        :return: The instant_app_parameters of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_parameters

    @instant_app_parameters.setter
    def instant_app_parameters(self, instant_app_parameters):
        """Sets the instant_app_parameters of this AddOrUpdateAutomationFulfillmentModel.

        Instant App parameters passed into the Instant App  # noqa: E501

        :param instant_app_parameters: The instant_app_parameters of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._instant_app_parameters = instant_app_parameters

    @property
    def instant_app_locale(self):
        """Gets the instant_app_locale of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Instant App locale  # noqa: E501

        :return: The instant_app_locale of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_locale

    @instant_app_locale.setter
    def instant_app_locale(self, instant_app_locale):
        """Sets the instant_app_locale of this AddOrUpdateAutomationFulfillmentModel.

        Instant App locale  # noqa: E501

        :param instant_app_locale: The instant_app_locale of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._instant_app_locale = instant_app_locale

    @property
    def upload_id(self):
        """Gets the upload_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Id of the upload to deliver  # noqa: E501

        :return: The upload_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: int
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this AddOrUpdateAutomationFulfillmentModel.

        Id of the upload to deliver  # noqa: E501

        :param upload_id: The upload_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: int
        """

        self._upload_id = upload_id

    @property
    def complete_conversation(self):
        """Gets the complete_conversation of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Should the conversation be removed from agent's active list  # noqa: E501

        :return: The complete_conversation of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: bool
        """
        return self._complete_conversation

    @complete_conversation.setter
    def complete_conversation(self, complete_conversation):
        """Sets the complete_conversation of this AddOrUpdateAutomationFulfillmentModel.

        Should the conversation be removed from agent's active list  # noqa: E501

        :param complete_conversation: The complete_conversation of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: bool
        """

        self._complete_conversation = complete_conversation

    @property
    def set_global_opt_out(self):
        """Gets the set_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Mark the contact as opted out for all channels  # noqa: E501

        :return: The set_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: bool
        """
        return self._set_global_opt_out

    @set_global_opt_out.setter
    def set_global_opt_out(self, set_global_opt_out):
        """Sets the set_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.

        Mark the contact as opted out for all channels  # noqa: E501

        :param set_global_opt_out: The set_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: bool
        """

        self._set_global_opt_out = set_global_opt_out

    @property
    def clear_global_opt_out(self):
        """Gets the clear_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Clear the flag marking the contact as opted out for all channels  # noqa: E501

        :return: The clear_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: bool
        """
        return self._clear_global_opt_out

    @clear_global_opt_out.setter
    def clear_global_opt_out(self, clear_global_opt_out):
        """Sets the clear_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.

        Clear the flag marking the contact as opted out for all channels  # noqa: E501

        :param clear_global_opt_out: The clear_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: bool
        """

        self._clear_global_opt_out = clear_global_opt_out

    @property
    def snippet_code(self):
        """Gets the snippet_code of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        JavaScript Snippet to be executed  # noqa: E501

        :return: The snippet_code of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._snippet_code

    @snippet_code.setter
    def snippet_code(self, snippet_code):
        """Sets the snippet_code of this AddOrUpdateAutomationFulfillmentModel.

        JavaScript Snippet to be executed  # noqa: E501

        :param snippet_code: The snippet_code of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._snippet_code = snippet_code

    @property
    def escalate_groups(self):
        """Gets the escalate_groups of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The escalate_groups of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._escalate_groups

    @escalate_groups.setter
    def escalate_groups(self, escalate_groups):
        """Sets the escalate_groups of this AddOrUpdateAutomationFulfillmentModel.


        :param escalate_groups: The escalate_groups of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._escalate_groups = escalate_groups

    @property
    def add_to_contact_lists(self):
        """Gets the add_to_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The add_to_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_to_contact_lists

    @add_to_contact_lists.setter
    def add_to_contact_lists(self, add_to_contact_lists):
        """Sets the add_to_contact_lists of this AddOrUpdateAutomationFulfillmentModel.


        :param add_to_contact_lists: The add_to_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._add_to_contact_lists = add_to_contact_lists

    @property
    def remove_from_contact_lists(self):
        """Gets the remove_from_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The remove_from_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._remove_from_contact_lists

    @remove_from_contact_lists.setter
    def remove_from_contact_lists(self, remove_from_contact_lists):
        """Sets the remove_from_contact_lists of this AddOrUpdateAutomationFulfillmentModel.


        :param remove_from_contact_lists: The remove_from_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._remove_from_contact_lists = remove_from_contact_lists

    @property
    def remove_from_all_contact_lists(self):
        """Gets the remove_from_all_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The remove_from_all_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: bool
        """
        return self._remove_from_all_contact_lists

    @remove_from_all_contact_lists.setter
    def remove_from_all_contact_lists(self, remove_from_all_contact_lists):
        """Sets the remove_from_all_contact_lists of this AddOrUpdateAutomationFulfillmentModel.


        :param remove_from_all_contact_lists: The remove_from_all_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: bool
        """

        self._remove_from_all_contact_lists = remove_from_all_contact_lists

    @property
    def add_tags(self):
        """Gets the add_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The add_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_tags

    @add_tags.setter
    def add_tags(self, add_tags):
        """Sets the add_tags of this AddOrUpdateAutomationFulfillmentModel.


        :param add_tags: The add_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._add_tags = add_tags

    @property
    def remove_tags(self):
        """Gets the remove_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The remove_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._remove_tags

    @remove_tags.setter
    def remove_tags(self, remove_tags):
        """Sets the remove_tags of this AddOrUpdateAutomationFulfillmentModel.


        :param remove_tags: The remove_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._remove_tags = remove_tags

    @property
    def data(self):
        """Gets the data of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The data of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this AddOrUpdateAutomationFulfillmentModel.


        :param data: The data of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: dict(str, str)
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddOrUpdateAutomationFulfillmentModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddOrUpdateAutomationFulfillmentModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TeamActivityEventModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'event_type': 'str',
        'activity': 'str',
        'timestamp': 'int',
        'id': 'int',
        'email': 'str',
        'active_conversations': 'int',
        'inbox_count': 'int',
        'total_slots': 'int',
        'auto_in': 'bool',
        'on_break': 'bool',
        'logged_in': 'bool',
        'connected': 'bool'
    }

    attribute_map = {
        'event_type': 'eventType',
        'activity': 'activity',
        'timestamp': 'timestamp',
        'id': 'id',
        'email': 'email',
        'active_conversations': 'activeConversations',
        'inbox_count': 'inboxCount',
        'total_slots': 'totalSlots',
        'auto_in': 'autoIn',
        'on_break': 'onBreak',
        'logged_in': 'loggedIn',
        'connected': 'connected'
    }

    def __init__(self, event_type=None, activity=None, timestamp=None, id=None, email=None, active_conversations=None, inbox_count=None, total_slots=None, auto_in=None, on_break=None, logged_in=None, connected=None):  # noqa: E501
        """TeamActivityEventModel - a model defined in Swagger"""  # noqa: E501
        self._event_type = None
        self._activity = None
        self._timestamp = None
        self._id = None
        self._email = None
        self._active_conversations = None
        self._inbox_count = None
        self._total_slots = None
        self._auto_in = None
        self._on_break = None
        self._logged_in = None
        self._connected = None
        self.discriminator = None
        if event_type is not None:
            self.event_type = event_type
        if activity is not None:
            self.activity = activity
        if timestamp is not None:
            self.timestamp = timestamp
        if id is not None:
            self.id = id
        if email is not None:
            self.email = email
        if active_conversations is not None:
            self.active_conversations = active_conversations
        if inbox_count is not None:
            self.inbox_count = inbox_count
        if total_slots is not None:
            self.total_slots = total_slots
        if auto_in is not None:
            self.auto_in = auto_in
        if on_break is not None:
            self.on_break = on_break
        if logged_in is not None:
            self.logged_in = logged_in
        if connected is not None:
            self.connected = connected

    @property
    def event_type(self):
        """Gets the event_type of this TeamActivityEventModel.  # noqa: E501

        The kind of event  # noqa: E501

        :return: The event_type of this TeamActivityEventModel.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this TeamActivityEventModel.

        The kind of event  # noqa: E501

        :param event_type: The event_type of this TeamActivityEventModel.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def activity(self):
        """Gets the activity of this TeamActivityEventModel.  # noqa: E501

        If the event is on-break-on, then the reason for the break  # noqa: E501

        :return: The activity of this TeamActivityEventModel.  # noqa: E501
        :rtype: str
        """
        return self._activity

    @activity.setter
    def activity(self, activity):
        """Sets the activity of this TeamActivityEventModel.

        If the event is on-break-on, then the reason for the break  # noqa: E501

        :param activity: The activity of this TeamActivityEventModel.  # noqa: E501
        :type: str
        """

        self._activity = activity

    @property
    def timestamp(self):
        """Gets the timestamp of this TeamActivityEventModel.  # noqa: E501

        Time event occurred  # noqa: E501

        :return: The timestamp of this TeamActivityEventModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this TeamActivityEventModel.

        Time event occurred  # noqa: E501

        :param timestamp: The timestamp of this TeamActivityEventModel.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def id(self):
        """Gets the id of this TeamActivityEventModel.  # noqa: E501

        The team member's id  # noqa: E501

        :return: The id of this TeamActivityEventModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TeamActivityEventModel.

        The team member's id  # noqa: E501

        :param id: The id of this TeamActivityEventModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def email(self):
        """Gets the email of this TeamActivityEventModel.  # noqa: E501

        The team member's email  # noqa: E501

        :return: The email of this TeamActivityEventModel.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this TeamActivityEventModel.

        The team member's email  # noqa: E501

        :param email: The email of this TeamActivityEventModel.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def active_conversations(self):
        """Gets the active_conversations of this TeamActivityEventModel.  # noqa: E501

        The number of active conversation the team member has  # noqa: E501

        :return: The active_conversations of this TeamActivityEventModel.  # noqa: E501
        :rtype: int
        """
        return self._active_conversations

    @active_conversations.setter
    def active_conversations(self, active_conversations):
        """Sets the active_conversations of this TeamActivityEventModel.

        The number of active conversation the team member has  # noqa: E501

        :param active_conversations: The active_conversations of this TeamActivityEventModel.  # noqa: E501
        :type: int
        """

        self._active_conversations = active_conversations

    @property
    def inbox_count(self):
        """Gets the inbox_count of this TeamActivityEventModel.  # noqa: E501

        The number of interactions in the inbox across the org  # noqa: E501

        :return: The inbox_count of this TeamActivityEventModel.  # noqa: E501
        :rtype: int
        """
        return self._inbox_count

    @inbox_count.setter
    def inbox_count(self, inbox_count):
        """Sets the inbox_count of this TeamActivityEventModel.

        The number of interactions in the inbox across the org  # noqa: E501

        :param inbox_count: The inbox_count of this TeamActivityEventModel.  # noqa: E501
        :type: int
        """

        self._inbox_count = inbox_count

    @property
    def total_slots(self):
        """Gets the total_slots of this TeamActivityEventModel.  # noqa: E501

        The maximum number of conversations the user will be added with auto-in on  # noqa: E501

        :return: The total_slots of this TeamActivityEventModel.  # noqa: E501
        :rtype: int
        """
        return self._total_slots

    @total_slots.setter
    def total_slots(self, total_slots):
        """Sets the total_slots of this TeamActivityEventModel.

        The maximum number of conversations the user will be added with auto-in on  # noqa: E501

        :param total_slots: The total_slots of this TeamActivityEventModel.  # noqa: E501
        :type: int
        """

        self._total_slots = total_slots

    @property
    def auto_in(self):
        """Gets the auto_in of this TeamActivityEventModel.  # noqa: E501

        Whether or not auto-in is enabled  # noqa: E501

        :return: The auto_in of this TeamActivityEventModel.  # noqa: E501
        :rtype: bool
        """
        return self._auto_in

    @auto_in.setter
    def auto_in(self, auto_in):
        """Sets the auto_in of this TeamActivityEventModel.

        Whether or not auto-in is enabled  # noqa: E501

        :param auto_in: The auto_in of this TeamActivityEventModel.  # noqa: E501
        :type: bool
        """

        self._auto_in = auto_in

    @property
    def on_break(self):
        """Gets the on_break of this TeamActivityEventModel.  # noqa: E501

        Whether or not the team member is on break  # noqa: E501

        :return: The on_break of this TeamActivityEventModel.  # noqa: E501
        :rtype: bool
        """
        return self._on_break

    @on_break.setter
    def on_break(self, on_break):
        """Sets the on_break of this TeamActivityEventModel.

        Whether or not the team member is on break  # noqa: E501

        :param on_break: The on_break of this TeamActivityEventModel.  # noqa: E501
        :type: bool
        """

        self._on_break = on_break

    @property
    def logged_in(self):
        """Gets the logged_in of this TeamActivityEventModel.  # noqa: E501

        Whether or not the team member is logged in  # noqa: E501

        :return: The logged_in of this TeamActivityEventModel.  # noqa: E501
        :rtype: bool
        """
        return self._logged_in

    @logged_in.setter
    def logged_in(self, logged_in):
        """Sets the logged_in of this TeamActivityEventModel.

        Whether or not the team member is logged in  # noqa: E501

        :param logged_in: The logged_in of this TeamActivityEventModel.  # noqa: E501
        :type: bool
        """

        self._logged_in = logged_in

    @property
    def connected(self):
        """Gets the connected of this TeamActivityEventModel.  # noqa: E501

        True if the team member is logged in AND has Prompt open in a browser tab  # noqa: E501

        :return: The connected of this TeamActivityEventModel.  # noqa: E501
        :rtype: bool
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """Sets the connected of this TeamActivityEventModel.

        True if the team member is logged in AND has Prompt open in a browser tab  # noqa: E501

        :param connected: The connected of this TeamActivityEventModel.  # noqa: E501
        :type: bool
        """

        self._connected = connected

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamActivityEventModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamActivityEventModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddScheduledActionModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'int',
        'org_channel_id': 'str',
        'customer_channel_id': 'str',
        'message': 'str',
        'whisper': 'str',
        'instant_app_schema_id': 'str',
        'instant_app_message': 'str',
        'instant_app_parameters': 'str',
        'instant_app_locale': 'str',
        'upload_id': 'int',
        'deliver_on': 'int',
        'topic': 'str'
    }

    attribute_map = {
        'user_id': 'userId',
        'org_channel_id': 'orgChannelId',
        'customer_channel_id': 'customerChannelId',
        'message': 'message',
        'whisper': 'whisper',
        'instant_app_schema_id': 'instantAppSchemaID',
        'instant_app_message': 'instantAppMessage',
        'instant_app_parameters': 'instantAppParameters',
        'instant_app_locale': 'instantAppLocale',
        'upload_id': 'uploadId',
        'deliver_on': 'deliverOn',
        'topic': 'topic'
    }

    def __init__(self, user_id=None, org_channel_id=None, customer_channel_id=None, message=None, whisper=None, instant_app_schema_id=None, instant_app_message=None, instant_app_parameters=None, instant_app_locale=None, upload_id=None, deliver_on=None, topic=None):  # noqa: E501
        """AddScheduledActionModel - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._org_channel_id = None
        self._customer_channel_id = None
        self._message = None
        self._whisper = None
        self._instant_app_schema_id = None
        self._instant_app_message = None
        self._instant_app_parameters = None
        self._instant_app_locale = None
        self._upload_id = None
        self._deliver_on = None
        self._topic = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        self.org_channel_id = org_channel_id
        if customer_channel_id is not None:
            self.customer_channel_id = customer_channel_id
        if message is not None:
            self.message = message
        if whisper is not None:
            self.whisper = whisper
        if instant_app_schema_id is not None:
            self.instant_app_schema_id = instant_app_schema_id
        if instant_app_message is not None:
            self.instant_app_message = instant_app_message
        if instant_app_parameters is not None:
            self.instant_app_parameters = instant_app_parameters
        if instant_app_locale is not None:
            self.instant_app_locale = instant_app_locale
        if upload_id is not None:
            self.upload_id = upload_id
        if deliver_on is not None:
            self.deliver_on = deliver_on
        if topic is not None:
            self.topic = topic

    @property
    def user_id(self):
        """Gets the user_id of this AddScheduledActionModel.  # noqa: E501

        ID of the team member that will deliver the Scheduled Action.  # noqa: E501

        :return: The user_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AddScheduledActionModel.

        ID of the team member that will deliver the Scheduled Action.  # noqa: E501

        :param user_id: The user_id of this AddScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def org_channel_id(self):
        """Gets the org_channel_id of this AddScheduledActionModel.  # noqa: E501

        The org channel apiId (or internal id) of the sending channel for message and Instant App actions  # noqa: E501

        :return: The org_channel_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._org_channel_id

    @org_channel_id.setter
    def org_channel_id(self, org_channel_id):
        """Sets the org_channel_id of this AddScheduledActionModel.

        The org channel apiId (or internal id) of the sending channel for message and Instant App actions  # noqa: E501

        :param org_channel_id: The org_channel_id of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """
        if org_channel_id is None:
            raise ValueError("Invalid value for `org_channel_id`, must not be `None`")  # noqa: E501

        self._org_channel_id = org_channel_id

    @property
    def customer_channel_id(self):
        """Gets the customer_channel_id of this AddScheduledActionModel.  # noqa: E501

        The customer channel apiId (or internal id) that will receive the message or Instant App actions.  # noqa: E501

        :return: The customer_channel_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_channel_id

    @customer_channel_id.setter
    def customer_channel_id(self, customer_channel_id):
        """Sets the customer_channel_id of this AddScheduledActionModel.

        The customer channel apiId (or internal id) that will receive the message or Instant App actions.  # noqa: E501

        :param customer_channel_id: The customer_channel_id of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._customer_channel_id = customer_channel_id

    @property
    def message(self):
        """Gets the message of this AddScheduledActionModel.  # noqa: E501

        The message to send to the user  # noqa: E501

        :return: The message of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AddScheduledActionModel.

        The message to send to the user  # noqa: E501

        :param message: The message of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def whisper(self):
        """Gets the whisper of this AddScheduledActionModel.  # noqa: E501

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :return: The whisper of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._whisper

    @whisper.setter
    def whisper(self, whisper):
        """Sets the whisper of this AddScheduledActionModel.

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :param whisper: The whisper of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._whisper = whisper

    @property
    def instant_app_schema_id(self):
        """Gets the instant_app_schema_id of this AddScheduledActionModel.  # noqa: E501

        Optional schema apiId (or internal id) used to create an instance of an Instant App.  # noqa: E501

        :return: The instant_app_schema_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_schema_id

    @instant_app_schema_id.setter
    def instant_app_schema_id(self, instant_app_schema_id):
        """Sets the instant_app_schema_id of this AddScheduledActionModel.

        Optional schema apiId (or internal id) used to create an instance of an Instant App.  # noqa: E501

        :param instant_app_schema_id: The instant_app_schema_id of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_schema_id = instant_app_schema_id

    @property
    def instant_app_message(self):
        """Gets the instant_app_message of this AddScheduledActionModel.  # noqa: E501

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :return: The instant_app_message of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_message

    @instant_app_message.setter
    def instant_app_message(self, instant_app_message):
        """Sets the instant_app_message of this AddScheduledActionModel.

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :param instant_app_message: The instant_app_message of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_message = instant_app_message

    @property
    def instant_app_parameters(self):
        """Gets the instant_app_parameters of this AddScheduledActionModel.  # noqa: E501

        Optional Instant App parameters passed into the Instant App  # noqa: E501

        :return: The instant_app_parameters of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_parameters

    @instant_app_parameters.setter
    def instant_app_parameters(self, instant_app_parameters):
        """Sets the instant_app_parameters of this AddScheduledActionModel.

        Optional Instant App parameters passed into the Instant App  # noqa: E501

        :param instant_app_parameters: The instant_app_parameters of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_parameters = instant_app_parameters

    @property
    def instant_app_locale(self):
        """Gets the instant_app_locale of this AddScheduledActionModel.  # noqa: E501

        Optional locale for the Instant App  # noqa: E501

        :return: The instant_app_locale of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_locale

    @instant_app_locale.setter
    def instant_app_locale(self, instant_app_locale):
        """Sets the instant_app_locale of this AddScheduledActionModel.

        Optional locale for the Instant App  # noqa: E501

        :param instant_app_locale: The instant_app_locale of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_locale = instant_app_locale

    @property
    def upload_id(self):
        """Gets the upload_id of this AddScheduledActionModel.  # noqa: E501


        :return: The upload_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this AddScheduledActionModel.


        :param upload_id: The upload_id of this AddScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._upload_id = upload_id

    @property
    def deliver_on(self):
        """Gets the deliver_on of this AddScheduledActionModel.  # noqa: E501

        The UTC timestamp the Scheduled Action will be delivered.  # noqa: E501

        :return: The deliver_on of this AddScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._deliver_on

    @deliver_on.setter
    def deliver_on(self, deliver_on):
        """Sets the deliver_on of this AddScheduledActionModel.

        The UTC timestamp the Scheduled Action will be delivered.  # noqa: E501

        :param deliver_on: The deliver_on of this AddScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._deliver_on = deliver_on

    @property
    def topic(self):
        """Gets the topic of this AddScheduledActionModel.  # noqa: E501

        Topic for the customer conversation.  # noqa: E501

        :return: The topic of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """Sets the topic of this AddScheduledActionModel.

        Topic for the customer conversation.  # noqa: E501

        :param topic: The topic of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._topic = topic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddScheduledActionModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddScheduledActionModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BulkActionVariantModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'message': 'str',
        'upload_id': 'int',
        'instant_app_schema': 'InstantAppSchemaModel',
        'instant_app_message': 'str',
        'instant_app_parameters': 'str',
        'instant_app_locale': 'str',
        'active': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'message': 'message',
        'upload_id': 'uploadId',
        'instant_app_schema': 'instantAppSchema',
        'instant_app_message': 'instantAppMessage',
        'instant_app_parameters': 'instantAppParameters',
        'instant_app_locale': 'instantAppLocale',
        'active': 'active'
    }

    def __init__(self, id=None, message=None, upload_id=None, instant_app_schema=None, instant_app_message=None, instant_app_parameters=None, instant_app_locale=None, active=None):  # noqa: E501
        """BulkActionVariantModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._message = None
        self._upload_id = None
        self._instant_app_schema = None
        self._instant_app_message = None
        self._instant_app_parameters = None
        self._instant_app_locale = None
        self._active = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if message is not None:
            self.message = message
        if upload_id is not None:
            self.upload_id = upload_id
        if instant_app_schema is not None:
            self.instant_app_schema = instant_app_schema
        if instant_app_message is not None:
            self.instant_app_message = instant_app_message
        if instant_app_parameters is not None:
            self.instant_app_parameters = instant_app_parameters
        if instant_app_locale is not None:
            self.instant_app_locale = instant_app_locale
        if active is not None:
            self.active = active

    @property
    def id(self):
        """Gets the id of this BulkActionVariantModel.  # noqa: E501

        The system generated unique id for this variant.  # noqa: E501

        :return: The id of this BulkActionVariantModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BulkActionVariantModel.

        The system generated unique id for this variant.  # noqa: E501

        :param id: The id of this BulkActionVariantModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def message(self):
        """Gets the message of this BulkActionVariantModel.  # noqa: E501

        The message to send to the user  # noqa: E501

        :return: The message of this BulkActionVariantModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this BulkActionVariantModel.

        The message to send to the user  # noqa: E501

        :param message: The message of this BulkActionVariantModel.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def upload_id(self):
        """Gets the upload_id of this BulkActionVariantModel.  # noqa: E501

        Id of the file to send to the user  # noqa: E501

        :return: The upload_id of this BulkActionVariantModel.  # noqa: E501
        :rtype: int
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this BulkActionVariantModel.

        Id of the file to send to the user  # noqa: E501

        :param upload_id: The upload_id of this BulkActionVariantModel.  # noqa: E501
        :type: int
        """

        self._upload_id = upload_id

    @property
    def instant_app_schema(self):
        """Gets the instant_app_schema of this BulkActionVariantModel.  # noqa: E501


        :return: The instant_app_schema of this BulkActionVariantModel.  # noqa: E501
        :rtype: InstantAppSchemaModel
        """
        return self._instant_app_schema

    @instant_app_schema.setter
    def instant_app_schema(self, instant_app_schema):
        """Sets the instant_app_schema of this BulkActionVariantModel.


        :param instant_app_schema: The instant_app_schema of this BulkActionVariantModel.  # noqa: E501
        :type: InstantAppSchemaModel
        """

        self._instant_app_schema = instant_app_schema

    @property
    def instant_app_message(self):
        """Gets the instant_app_message of this BulkActionVariantModel.  # noqa: E501

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :return: The instant_app_message of this BulkActionVariantModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_message

    @instant_app_message.setter
    def instant_app_message(self, instant_app_message):
        """Sets the instant_app_message of this BulkActionVariantModel.

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :param instant_app_message: The instant_app_message of this BulkActionVariantModel.  # noqa: E501
        :type: str
        """

        self._instant_app_message = instant_app_message

    @property
    def instant_app_parameters(self):
        """Gets the instant_app_parameters of this BulkActionVariantModel.  # noqa: E501

        Instant App parameters passed into the Instant App  # noqa: E501

        :return: The instant_app_parameters of this BulkActionVariantModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_parameters

    @instant_app_parameters.setter
    def instant_app_parameters(self, instant_app_parameters):
        """Sets the instant_app_parameters of this BulkActionVariantModel.

        Instant App parameters passed into the Instant App  # noqa: E501

        :param instant_app_parameters: The instant_app_parameters of this BulkActionVariantModel.  # noqa: E501
        :type: str
        """

        self._instant_app_parameters = instant_app_parameters

    @property
    def instant_app_locale(self):
        """Gets the instant_app_locale of this BulkActionVariantModel.  # noqa: E501

        Instant App locale  # noqa: E501

        :return: The instant_app_locale of this BulkActionVariantModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_locale

    @instant_app_locale.setter
    def instant_app_locale(self, instant_app_locale):
        """Sets the instant_app_locale of this BulkActionVariantModel.

        Instant App locale  # noqa: E501

        :param instant_app_locale: The instant_app_locale of this BulkActionVariantModel.  # noqa: E501
        :type: str
        """

        self._instant_app_locale = instant_app_locale

    @property
    def active(self):
        """Gets the active of this BulkActionVariantModel.  # noqa: E501

        Whether the variant is still being used. If false, the variant was disabled before the broadcast completed, and unsent messages that where supposed to use that variant, were redistributed to other variants  # noqa: E501

        :return: The active of this BulkActionVariantModel.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this BulkActionVariantModel.

        Whether the variant is still being used. If false, the variant was disabled before the broadcast completed, and unsent messages that where supposed to use that variant, were redistributed to other variants  # noqa: E501

        :param active: The active of this BulkActionVariantModel.  # noqa: E501
        :type: bool
        """

        self._active = active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BulkActionVariantModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulkActionVariantModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsCustomerEngagementReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp_epoch': 'int',
        'active_customers': 'int',
        'engaged_customers': 'int',
        'new_customers': 'int',
        'customer_opt_outs': 'int'
    }

    attribute_map = {
        'timestamp_epoch': 'timestampEpoch',
        'active_customers': 'activeCustomers',
        'engaged_customers': 'engagedCustomers',
        'new_customers': 'newCustomers',
        'customer_opt_outs': 'customerOptOuts'
    }

    def __init__(self, timestamp_epoch=None, active_customers=None, engaged_customers=None, new_customers=None, customer_opt_outs=None):  # noqa: E501
        """AnalyticsCustomerEngagementReportModel - a model defined in Swagger"""  # noqa: E501
        self._timestamp_epoch = None
        self._active_customers = None
        self._engaged_customers = None
        self._new_customers = None
        self._customer_opt_outs = None
        self.discriminator = None
        if timestamp_epoch is not None:
            self.timestamp_epoch = timestamp_epoch
        if active_customers is not None:
            self.active_customers = active_customers
        if engaged_customers is not None:
            self.engaged_customers = engaged_customers
        if new_customers is not None:
            self.new_customers = new_customers
        if customer_opt_outs is not None:
            self.customer_opt_outs = customer_opt_outs

    @property
    def timestamp_epoch(self):
        """Gets the timestamp_epoch of this AnalyticsCustomerEngagementReportModel.  # noqa: E501

        The timestamp at the start of the default group-by window.  # noqa: E501

        :return: The timestamp_epoch of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp_epoch

    @timestamp_epoch.setter
    def timestamp_epoch(self, timestamp_epoch):
        """Sets the timestamp_epoch of this AnalyticsCustomerEngagementReportModel.

        The timestamp at the start of the default group-by window.  # noqa: E501

        :param timestamp_epoch: The timestamp_epoch of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :type: int
        """

        self._timestamp_epoch = timestamp_epoch

    @property
    def active_customers(self):
        """Gets the active_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501

        The number of active customers in this group-by window.  # noqa: E501

        :return: The active_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :rtype: int
        """
        return self._active_customers

    @active_customers.setter
    def active_customers(self, active_customers):
        """Sets the active_customers of this AnalyticsCustomerEngagementReportModel.

        The number of active customers in this group-by window.  # noqa: E501

        :param active_customers: The active_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :type: int
        """

        self._active_customers = active_customers

    @property
    def engaged_customers(self):
        """Gets the engaged_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501

        The number of engaged customers in this group-by window.  # noqa: E501

        :return: The engaged_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :rtype: int
        """
        return self._engaged_customers

    @engaged_customers.setter
    def engaged_customers(self, engaged_customers):
        """Sets the engaged_customers of this AnalyticsCustomerEngagementReportModel.

        The number of engaged customers in this group-by window.  # noqa: E501

        :param engaged_customers: The engaged_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :type: int
        """

        self._engaged_customers = engaged_customers

    @property
    def new_customers(self):
        """Gets the new_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501

        The number of new customers in this group-by window.  # noqa: E501

        :return: The new_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :rtype: int
        """
        return self._new_customers

    @new_customers.setter
    def new_customers(self, new_customers):
        """Sets the new_customers of this AnalyticsCustomerEngagementReportModel.

        The number of new customers in this group-by window.  # noqa: E501

        :param new_customers: The new_customers of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :type: int
        """

        self._new_customers = new_customers

    @property
    def customer_opt_outs(self):
        """Gets the customer_opt_outs of this AnalyticsCustomerEngagementReportModel.  # noqa: E501

        The number of customer Opt-Outs in this group-by window.  # noqa: E501

        :return: The customer_opt_outs of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :rtype: int
        """
        return self._customer_opt_outs

    @customer_opt_outs.setter
    def customer_opt_outs(self, customer_opt_outs):
        """Sets the customer_opt_outs of this AnalyticsCustomerEngagementReportModel.

        The number of customer Opt-Outs in this group-by window.  # noqa: E501

        :param customer_opt_outs: The customer_opt_outs of this AnalyticsCustomerEngagementReportModel.  # noqa: E501
        :type: int
        """

        self._customer_opt_outs = customer_opt_outs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsCustomerEngagementReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsCustomerEngagementReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddOrUpdateSmartLinkModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'destination_link': 'str',
        'smart_domain': 'str',
        'extension': 'str',
        'preview_description': 'str',
        'preview_image': 'str',
        'fulfillment': 'AddOrUpdateSmartLinkFulfillmentModel'
    }

    attribute_map = {
        'name': 'name',
        'destination_link': 'destinationLink',
        'smart_domain': 'smartDomain',
        'extension': 'extension',
        'preview_description': 'previewDescription',
        'preview_image': 'previewImage',
        'fulfillment': 'fulfillment'
    }

    def __init__(self, name=None, destination_link=None, smart_domain=None, extension=None, preview_description=None, preview_image=None, fulfillment=None):  # noqa: E501
        """AddOrUpdateSmartLinkModel - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._destination_link = None
        self._smart_domain = None
        self._extension = None
        self._preview_description = None
        self._preview_image = None
        self._fulfillment = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if destination_link is not None:
            self.destination_link = destination_link
        if smart_domain is not None:
            self.smart_domain = smart_domain
        if extension is not None:
            self.extension = extension
        if preview_description is not None:
            self.preview_description = preview_description
        if preview_image is not None:
            self.preview_image = preview_image
        if fulfillment is not None:
            self.fulfillment = fulfillment

    @property
    def name(self):
        """Gets the name of this AddOrUpdateSmartLinkModel.  # noqa: E501

        The display name of this smart link.  # noqa: E501

        :return: The name of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddOrUpdateSmartLinkModel.

        The display name of this smart link.  # noqa: E501

        :param name: The name of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def destination_link(self):
        """Gets the destination_link of this AddOrUpdateSmartLinkModel.  # noqa: E501


        :return: The destination_link of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :rtype: str
        """
        return self._destination_link

    @destination_link.setter
    def destination_link(self, destination_link):
        """Sets the destination_link of this AddOrUpdateSmartLinkModel.


        :param destination_link: The destination_link of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :type: str
        """

        self._destination_link = destination_link

    @property
    def smart_domain(self):
        """Gets the smart_domain of this AddOrUpdateSmartLinkModel.  # noqa: E501


        :return: The smart_domain of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :rtype: str
        """
        return self._smart_domain

    @smart_domain.setter
    def smart_domain(self, smart_domain):
        """Sets the smart_domain of this AddOrUpdateSmartLinkModel.


        :param smart_domain: The smart_domain of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :type: str
        """

        self._smart_domain = smart_domain

    @property
    def extension(self):
        """Gets the extension of this AddOrUpdateSmartLinkModel.  # noqa: E501


        :return: The extension of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :rtype: str
        """
        return self._extension

    @extension.setter
    def extension(self, extension):
        """Sets the extension of this AddOrUpdateSmartLinkModel.


        :param extension: The extension of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :type: str
        """

        self._extension = extension

    @property
    def preview_description(self):
        """Gets the preview_description of this AddOrUpdateSmartLinkModel.  # noqa: E501


        :return: The preview_description of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :rtype: str
        """
        return self._preview_description

    @preview_description.setter
    def preview_description(self, preview_description):
        """Sets the preview_description of this AddOrUpdateSmartLinkModel.


        :param preview_description: The preview_description of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :type: str
        """

        self._preview_description = preview_description

    @property
    def preview_image(self):
        """Gets the preview_image of this AddOrUpdateSmartLinkModel.  # noqa: E501


        :return: The preview_image of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :rtype: str
        """
        return self._preview_image

    @preview_image.setter
    def preview_image(self, preview_image):
        """Sets the preview_image of this AddOrUpdateSmartLinkModel.


        :param preview_image: The preview_image of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :type: str
        """

        self._preview_image = preview_image

    @property
    def fulfillment(self):
        """Gets the fulfillment of this AddOrUpdateSmartLinkModel.  # noqa: E501


        :return: The fulfillment of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :rtype: AddOrUpdateSmartLinkFulfillmentModel
        """
        return self._fulfillment

    @fulfillment.setter
    def fulfillment(self, fulfillment):
        """Sets the fulfillment of this AddOrUpdateSmartLinkModel.


        :param fulfillment: The fulfillment of this AddOrUpdateSmartLinkModel.  # noqa: E501
        :type: AddOrUpdateSmartLinkFulfillmentModel
        """

        self._fulfillment = fulfillment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddOrUpdateSmartLinkModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddOrUpdateSmartLinkModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
